==> snobol4-2.0p1.tgz: lib/snobol4/2.0/include/config.h <==
/*
 * generated Wed Sep 30 16:38:38 MDT 2020
 * on amd64-1.ports.openbsd.org (OpenBSD)
 * by $Id: configure,v 1.278 2015/01/02 04:54:27 phil Exp $
 */

#define CONFIG_OPTIONS "--prefix=/usr/local --opt=-O2 -pipe  "
#define CONFIG_HOST "amd64-1.ports.openbsd.org"
#define CONFIG_DATE "Wed Sep 30 16:38:38 MDT 2020"
#define DIR_SEP "/"
#define PATH_SEP ":"
#define OBJECT_EXT ".o"
#define SETUP_SYS "posix"
#define SHARED_OBJ_SUBDIR "shared"
#define PML_SERV
#define HAVE_BUILD_VARS
#define NO_BITFIELDS
#define SIZLIM (~(VFLD_T)0)
#define REAL_T double
#define REALST_FORMAT "%.15lg"
#define SIZEOF_INT_T	8	/* for use in ifdefs */
#define SIZEOF_REAL_T	8	/* for use in ifdefs */
#define HAVE_STDLIB_H
#define HAVE_UNISTD_H
#define HAVE_ISFINITE
#define HAVE_STRINGS_H
#define HAVE_STRING_H
#define HAVE_SOCKADDR_IN6
#define SOCKLEN_T socklen_t
/* vfork() in unistd.h */
#define HAVE_FORKPTY
#define HAVE_UTIL_H
#define HAVE_PATHS_H
#define SNOLIB_BASE "/usr/local/lib/snobol4"
#define SNOLIB_DIR "/usr/local/lib/snobol4/2.0/lib"
#define INCLUDE_DIR "/usr/local/lib/snobol4/2.0/include"
/* NOTE: SNOLIB_FILE in config.m4 too! */
#define SNOLIB_FILE "snolib.so"
#define HAVE_FSEEKO
#define HAVE_GETTIMEOFDAY
#define HAVE_TM_GMTOFF
#define HAVE_SLEEP
#define HAVE_STRPTIME
#define HAVE_TIMEGM
/* Shared Object Libraries (in config.m4 too) */
#define SO_EXT ".so"
#define SO_CFLAGS "-fPIC"
#define SO_LD "cc"
#define SO_LDFLAGS "-shared -fPIC"
/* Dynamicly Loaded Extensions (in config.m4 too) */
#define DL_EXT ".so"
#define DL_CFLAGS "-fPIC"
#define DL_LD "cc"
#define DL_LDFLAGS "-shared -fPIC"
#define HAVE_NDBM_H
#define COMPILER_READLINE
#define HAVE_LSTAT
/* from CFLAGS: */
#define BLOCKS

/* if the file local-defines existed it would have been incorporated here */

==> snobol4-2.2.1.tgz: lib/snobol4/2.2.1/include/config.h <==
/*
 * generated Thu Apr 22 20:25:51 MDT 2021
 * on powerpc64.ports.openbsd.org (OpenBSD)
 * by $Id: configure,v 1.421 2020-12-18 22:59:11 phil Exp $
 */

#define CONFIG_OPTIONS "--prefix=/usr/local --opt=-O2 -pipe  "
#define CONFIG_HOST "powerpc64.ports.openbsd.org"
#define CONFIG_DATE "Thu Apr 22 20:25:51 MDT 2021"
#define DIR_SEP "/"
#define PATH_SEP ":"
#define OBJECT_EXT ".o"
#define SETUP_SYS "posix"
#define SHARED_OBJ_SUBDIR "shared"
#define PML_SERV
#define CC_IS "clang"
#define SIZEOF_LONG 8
#define NO_BITFIELDS
#define SIZLIM (~(VFLD_T)0)
#define REAL_T double
#define REALST_FORMAT "%.15lg"
#define SIZEOF_INT_T	8	/* for use in ifdefs */
#define SIZEOF_REAL_T	8	/* for use in ifdefs */
#define HAVE_UNISTD_H
#define HAVE_STDINT_H
#define HAVE_ISFINITE
#define GETRUSAGE_BUG
#define USE_MEMMOVE
#define HAVE_SOCKADDR_IN6
#define SOCKLEN_T socklen_t
/* vfork() in unistd.h */
#define TLS_IO
#define HAVE_UTIL_H
#define HAVE_PATHS_H
#define SNOLIB_BASE "/usr/local/lib/snobol4"
#define SNOLIB_DIR "/usr/local/lib/snobol4/2.2.1/lib"
#define INCLUDE_DIR "/usr/local/lib/snobol4/2.2.1/include"
#define HAVE_FSEEKO
#define HAVE_STRFTIME
#define EXPORT(TYPE) __attribute__ ((__visibility__("default"))) TYPE
/* Shared Object Libraries (in config.m4 too) */
#define SO_EXT ".so"
#define SO_CFLAGS "-fPIC -fvisibility=hidden"
#define SO_LD "cc"
#define SO_LDFLAGS "-shared -fPIC"
/* Dynamicly Loaded Extensions (in config.m4 too) */
#define DL_EXT ".so"
#define DL_CFLAGS "-fPIC"
#define DL_LD "cc"
#define DL_LDFLAGS "-shared -fPIC"
#define HAVE_READLINE
#define COMPILER_READLINE
#define HAVE_RL_SET_KEYMAP
#define USE_ZLIB
#define HAVE_NDBM_H
#define HAVE_LSTAT
#define USE_COMPIO
/* from CFLAGS: */
#define BLOCKS

/* if the file local-defines existed it would have been incorporated here */
